package main

import (
	"fmt"
	"log"
	"os"

	cnf "git.pbiernat.dev/egommerce/basket-service/pkg/config"

	"git.pbiernat.dev/egommerce/basket-service/internal/app/server"
	"git.pbiernat.dev/egommerce/basket-service/internal/common"
)

func main() {
	if cnf.ErrLoadingEnvs != nil {
		log.Panicln("Error loading .env file", cnf.ErrLoadingEnvs)
	}

	c := common.NewConfig()
	srv := server.New(
		c,
		server.WithCache(c),
		server.WithDatabase(c),
		server.WithEventbus(c),
		server.WithLogger(c),
		server.WithRegistry(c),
	)

	forever := make(chan struct{})

	err := srv.Base.Start(forever, srv.Shutdown())
	// server.SetupMiddleware(srv)
	// server.SetupRouter(srv)

	<-forever

	if err != nil {
		log.Fatalf("Failed to start server. Reason: %v\n", err)
		os.Exit(1)
	}

	fmt.Println("Done.")
	os.Exit(0)

	// c.AppDomain = cnf.GetEnv("APP_DOMAIN", defAppDomain)
	// c.Port, _ = strconv.Atoi(c.NetAddr[1:])
	// c.KVNamespace = cnf.GetEnv("APP_KV_NAMESPACE", defKVNmspc)

	// logHost, logPort := fluentd.ParseAddr(c.LoggerAddr)
	// logger := fluentd.NewLogger(c.GetAppFullName(), logHost, logPort)
	// defer logger.Close()

	// db conn
	// dbConn, err := database.Connect(c.DbURL)
	// if err != nil { // fixme: add wait-for-db...
	// 	logger.Log("Failed to connect to Database server: %v\n", err)
	// 	os.Exit(1)
	// }
	// defer dbConn.Close()

	// redis conn
	// redis := redis.NewClient(&redis.Options{
	// 	Addr:     c.CacheAddr,
	// 	Password: c.CachePassword,
	// 	DB:       0,
	// })
	// defer redis.Close()

	// eventbus conn
	// ebConn, ebCh, err := amqp.Open(c.EventBusURL)
	// if err != nil {
	// 	logger.Log("Failed to connect to EventBus server: %v\n", err)
	// 	os.Exit(1)
	// }
	// defer ebCh.Close()
	// defer amqp.Close(ebConn)

	// err = amqp.NewExchange(ebCh, c.EventBusExchange)
	// if err != nil {
	// 	logger.Log("Failed to declare EventBus exchange: %v\n", err)
	// 	os.Exit(1)
	// }
}
